@@ -460,22 +460,21 @@ class Client(object):
                     time.sleep(11)
                     logging.debug("Re-establishing stream . . . ")
                     try:
-                        resp = self.session.request("get", url)
+                        resp = requests.request("get", url)
                     except requests.exceptions.ConnectionError:
                         time.sleep(180)
                         self.session = self._session()
-                        resp = self.session.request("get", url)
+                        resp = requests.request("get", url)
                     if resp.status_code == 429:
                         logging.debug("Server requires hard timeout: 3 minute delay.")
                         time.sleep(180)
                         logging.debug("Re-establishing stream . . . ")
-                        self.session = self._session() # Reset session to avoid API throttle
-                        resp = self.session.request("get", url)
+                        resp = requests.request("get", url)
                         if resp.status_code == 429:
                             logging.debug("Server requires hard timeout: 5 minute delay.")
                             time.sleep(300)
                             logging.debug("Re-establishing stream . . . ")
-                            resp = self.session.request("get", url)
+                            resp = requests.request("get", url)
                         else:
                             pass
                 else:
